MODULE CollapseFraction
!-----------------------------------------------------------------------------
! Read in, tabulate, and interpolate the collapse fraction.
! The input file is in the following format:
!
! [1st column] redshift 
! [2nd column] collapse fraction
!
! December 28, 2010: E. Komatsu
!-----------------------------------------------------------------------------
  IMPLICIT none
  integer :: jlo,ndata
  DOUBLE PRECISION, dimension(:), allocatable :: xa,ya,y2a
contains
  SUBROUTINE Open_Fcoll(filename,n)
    IMPLICIT none
    DOUBLE PRECISION, dimension(:), allocatable :: redshift,fcoll
    CHARACTER(len=128) :: filename
    INTEGER, intent(IN) :: n
    INTEGER :: i
    ndata=n
    ALLOCATE(xa(ndata),ya(ndata),y2a(ndata))
    ALLOCATE(redshift(ndata),fcoll(ndata))
    open(1,file=filename,status='old',form='formatted')
    print*,'read in '//trim(filename)
    do i=1,ndata
       read(1,*)redshift(i),fcoll(i)
    enddo
    close(1)
    xa=redshift
    ya=dlog(fcoll)
    DEALLOCATE(redshift,fcoll)
    CALL spline(xa,ya,ndata,1.d30,1.d30,y2a)
    return
  END SUBROUTINE Open_Fcoll
  SUBROUTINE Close_Fcoll
    DEALLOCATE(xa,ya,y2a)
    return
  END SUBROUTINE Close_Fcoll
END MODULE CollapseFraction
DOUBLE PRECISION FUNCTION Fcoll(z)
  Use CollapseFraction
  IMPLICIT none
  DOUBLE PRECISION :: a,b,h,x,y,z
  x=z
  CALL hunt(xa,ndata,x,jlo)
  h=xa(jlo+1)-xa(jlo)
  a=(xa(jlo+1)-x)/h
  b=(x-xa(jlo))/h
  y=a*ya(jlo)+b*ya(jlo+1)+((a**3-a)*y2a(jlo)+(b**3-b)*y2a(jlo+1))*(h**2)/6.
  Fcoll = dexp(y)
  return
END FUNCTION Fcoll
